==> haskell-tf-random-0.5-483-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tf-random
version:              0.5
visibility:           public
id:                   tf-random-0.5-GqWFLMnVxxiLPKaD1uEQml
key:                  tf-random-0.5-GqWFLMnVxxiLPKaD1uEQml
license:              BSD-3-Clause
maintainer:           Michał Pałka <michal.palka@chalmers.se>
author:               Michał Pałka <michal.palka@chalmers.se>
synopsis:             High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.

    The package provides the following:

    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.

    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.

    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.

    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.

    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.

    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.

category:             Random
abi:                  c25c8849c8dc53c45d5cc4a59f8f0f83
exposed:              True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tf-random-0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tf-random
hs-libraries:         HStf-random-0.5-GqWFLMnVxxiLPKaD1uEQml
depends:
    base-4.15.1.0 primitive-0.7.3.0-8OGcgOY0vHCJaje3xtWYyl
    random-1.2.1-1Hz8B867VBj7K7atSeCZU3 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html:         /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tf-random-0.5-487-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tf-random
version:              0.5
visibility:           public
id:                   tf-random-0.5-D1cj6XeJndmL6ePUzI1hyK
key:                  tf-random-0.5-D1cj6XeJndmL6ePUzI1hyK
license:              BSD-3-Clause
maintainer:           Michał Pałka <michal.palka@chalmers.se>
author:               Michał Pałka <michal.palka@chalmers.se>
synopsis:             High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.

    The package provides the following:

    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.

    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.

    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.

    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.

    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.

    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.

category:             Random
abi:                  4cd1c41ed2065b8b3d61e24031405991
exposed:              True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tf-random-0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tf-random
hs-libraries:         HStf-random-0.5-D1cj6XeJndmL6ePUzI1hyK
depends:
    base-4.15.1.0 primitive-0.7.3.0-H7ArDzjx1emFJWugXBDX59
    random-1.2.1-E3c41PA01kCLyHrUUW2INz time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html:         /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
